@@ -41,7 +41,9 @@ class Domoticz(IPlugin):
 		if entity == "dz_loc_frisquet"  :
 			on_off = jsonInput['outcome']['entities']['on_off']['value']
 			location = jsonInput['outcome']['entities']['location']['body']
-		idex= location + "_" + on_off
+		idex= entity + "_" + location + "_" + on_off
+		if on_off == "allume" :
+			on_off = "on"
 		log.msg("index :  %s" % (idex))		
 		for rs in self.configuration_plugin['param_dz']:
 #			log.msg("ids  :  %s" % (rs['ids']))
